==> ckan-2.8.5.tar.gz: ckan-2.8.5/ckan/public/base/i18n/pt_BR.js <==
{
  "": {
    "domain": "ckan", 
    "lang": "pt_BR", 
    "plural-forms": "nplurals=2; plural=(n > 1);"
  }, 
  "%(color)s shirt": [
    "%(color)s shirts", 
    "", 
    ""
  ], 
  "%(num)d item": [
    "%(num)d items", 
    "", 
    ""
  ], 
  "%(num)d missing translation": [
    "%(num)d missing translations", 
    "", 
    ""
  ], 
  "Add Filter": [
    null, 
    "Adicionar Filtro"
  ], 
  "An Error Occurred": [
    null, 
    "Ocorreu um erro"
  ], 
  "Are you sure you want to perform this action?": [
    null, 
    "Você tem certeza de que deseja executar essa ação?"
  ], 
  "Cancel": [
    null, 
    "Cancelar"
  ], 
  "Confirm": [
    null, 
    "Confirme"
  ], 
  "Could not load view": [
    null, 
    "Não foi possível carregar a visão"
  ], 
  "DataProxy returned an error": [
    null, 
    "DataPorxy retornou um erro"
  ], 
  "DataStore returned an error": [
    null, 
    "DataStore retornou um erro"
  ], 
  "Edit": [
    null, 
    "Editar"
  ], 
  "Failed to load data API information": [
    null, 
    "Falhou em carregar informações sobre a API de dados"
  ], 
  "File": [
    null, 
    "Arquivo"
  ], 
  "Filters": [
    null, 
    "Filtros"
  ], 
  "Follow": [
    null, 
    "Seguir"
  ], 
  "Graph": [
    null, 
    "Gráfico"
  ], 
  "Grid": [
    null, 
    "Grade"
  ], 
  "Hide": [
    null, 
    "Ocultar"
  ], 
  "Image": [
    null, 
    "Imagem"
  ], 
  "Input is too short, must be at least one character": [
    "Input is too short, must be at least %(num)d characters", 
    "A entrada é curta demais, deve possuir pelo menos um caractere", 
    "A entrada é curta demais, deve possuir pelo menos %(num)d caracteres"
  ], 
  "Link": [
    null, 
    "Link"
  ], 
  "Link to a URL on the internet (you can also link to an API)": [
    null, 
    "Link para uma URL na internet (você também pode ligar a uma API)"
  ], 
  "Loading...": [
    null, 
    "Carregando ..."
  ], 
  "Map": [
    null, 
    "Mapa"
  ], 
  "No matches found": [
    null, 
    "Nenhum resultado encontrado"
  ], 
  "Please Confirm Action": [
    null, 
    "Favor confirmar a ação"
  ], 
  "Remove": [
    null, 
    "Remover"
  ], 
  "Reorder resources": [
    null, 
    "Reordenar recursos"
  ], 
  "Resource uploaded": [
    null, 
    "Recurso enviado"
  ], 
  "Save order": [
    null, 
    "Salvar ordem"
  ], 
  "Saving...": [
    null, 
    "Salvando..."
  ], 
  "Select a field": [
    null, 
    "Selecione um campo"
  ], 
  "Show more": [
    null, 
    "Mostrar mais"
  ], 
  "Start typing…": [
    null, 
    "Comece a digitar ..."
  ], 
  "There are unsaved modifications to this form": [
    null, 
    "Há modificações não salvas neste formulário"
  ], 
  "There is no API data to load for this resource": [
    null, 
    "Não existe API de dados para carregar para este recurso"
  ], 
  "URL": [
    null, 
    "URL"
  ], 
  "Unable to authenticate upload": [
    null, 
    "Não foi possível autenticar o envio"
  ], 
  "Unable to get data for uploaded file": [
    null, 
    "Não foi possível obter os dados do arquivo carregado"
  ], 
  "Unable to upload file": [
    null, 
    "Não foi possível enviar o arquivo"
  ], 
  "Unfollow": [
    null, 
    "Deixar de seguir"
  ], 
  "Upload": [
    null, 
    "Enviar"
  ], 
  "Upload a file": [
    null, 
    "Carrega um arquivo"
  ], 
  "Upload a file on your computer": [
    null, 
    "Enviar um arquivo do seu computador"
  ], 
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null, 
    "Você está enviando um arquivo. Tem certeza de que quer navegar para outra página e parar esse envio?"
  ], 
  "bar": [
    "bars", 
    "", 
    ""
  ], 
  "error loading view": [
    null, 
    "erro ao carregar visualização"
  ], 
  "foo": [
    null, 
    "foo"
  ], 
  "no %(attr)s translation": [
    "no %(attr)s translations", 
    "", 
    ""
  ], 
  "no translation": [
    "no translations", 
    "", 
    ""
  ]
}

==> ckan-2.9.9.tar.gz: ckan-2.9.9/ckan/public/base/i18n/pt_BR.js <==
{
  "": {
    "domain": "ckan",
    "lang": "pt_BR",
    "plural-forms": "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;"
  },
  "Add Filter": [
    null,
    "Adicionar Filtro"
  ],
  "An Error Occurred": [
    null,
    "Ocorreu um erro"
  ],
  "Are you sure you want to perform this action?": [
    null,
    "Você tem certeza de que deseja executar essa ação?"
  ],
  "Cancel": [
    null,
    "Cancelar"
  ],
  "Confirm": [
    null,
    "Confirme"
  ],
  "Could not load view": [
    null,
    "Não foi possível carregar a visão"
  ],
  "DataProxy returned an error": [
    null,
    "DataPorxy retornou um erro"
  ],
  "DataStore returned an error": [
    null,
    "DataStore retornou um erro"
  ],
  "Edit": [
    null,
    "Editar"
  ],
  "Failed to load data API information": [
    null,
    "Falhou em carregar informações sobre a API de dados"
  ],
  "File": [
    null,
    "Arquivo"
  ],
  "Filters": [
    null,
    "Filtros"
  ],
  "Follow": [
    null,
    "Seguir"
  ],
  "Graph": [
    null,
    "Gráfico"
  ],
  "Grid": [
    null,
    "Grade"
  ],
  "Hide": [
    null,
    "Ocultar"
  ],
  "Image": [
    null,
    "Imagem"
  ],
  "Input is too short, must be at least one character": [
    "Input is too short, must be at least %(num)d characters",
    "A entrada é curta demais, deve possuir pelo menos um caractere",
    "A entrada é curta demais, deve possuir pelo menos %(num)d caracteres",
    "A entrada é curta demais, deve possuir pelo menos %(num)d caracteres"
  ],
  "Link": [
    null,
    "Link"
  ],
  "Link to a URL on the internet (you can also link to an API)": [
    null,
    "Link para uma URL na internet (você também pode ligar a uma API)"
  ],
  "Loading...": [
    null,
    "Carregando ..."
  ],
  "Map": [
    null,
    "Mapa"
  ],
  "No matches found": [
    null,
    "Nenhum resultado encontrado"
  ],
  "Please Confirm Action": [
    null,
    "Favor confirmar a ação"
  ],
  "Remove": [
    null,
    "Remover"
  ],
  "Reorder resources": [
    null,
    "Reordenar recursos"
  ],
  "Resource uploaded": [
    null,
    "Recurso enviado"
  ],
  "Save order": [
    null,
    "Salvar ordem"
  ],
  "Saving...": [
    null,
    "Salvando..."
  ],
  "Select a field": [
    null,
    "Selecione um campo"
  ],
  "Show more": [
    null,
    "Mostrar mais"
  ],
  "Start typing…": [
    null,
    "Comece a digitar ..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "Há modificações não salvas neste formulário"
  ],
  "There is no API data to load for this resource": [
    null,
    "Não existe API de dados para carregar para este recurso"
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "Não foi possível autenticar o envio"
  ],
  "Unable to get data for uploaded file": [
    null,
    "Não foi possível obter os dados do arquivo carregado"
  ],
  "Unable to upload file": [
    null,
    "Não foi possível enviar o arquivo"
  ],
  "Unfollow": [
    null,
    "Deixar de seguir"
  ],
  "Upload": [
    null,
    "Enviar"
  ],
  "Upload a file": [
    null,
    "Carrega um arquivo"
  ],
  "Upload a file on your computer": [
    null,
    "Enviar um arquivo do seu computador"
  ],
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null,
    "Você está enviando um arquivo. Tem certeza de que quer navegar para outra página e parar esse envio?"
  ],
  "error loading view": [
    null,
    "erro ao carregar visualização"
  ]
}
